#jp-header #jp-clouds {
	background-position: -632px 100%;
}

#jp-header.small #jp-clouds {
	background-position: -425px 100%;
}

#jp-header #jp-clouds #jp-disconnect {
	float: left;
	margin: -35px 0 0 25px;
	text-align: left;
}

#jp-header #jp-clouds #jp-disconnect a {
	background-position: 100% 90%;
	padding: 4px 30px 3px 10px;
}

#jp-header #jp-clouds #jp-disconnect a:hover {
	background-position: 100% 3%;
}

#jp-header h3 {
	background-position: top right;
	right: 25px;
	left: auto;
}

#jp-header p {
	right: 390px;
	left: auto;
	text-align: right;
}

#jp-info {
	margin: 0 28px 0 12px;
}

#jp-info p {
	float:right;
}

#jp-info a.jp-button {
	float: left;
	margin: 8px 20px 0 0;
}

.jp-connect {
	padding: 10px 0 5px !important;
}

#jetpack-settings > .jetpack-message {
	margin: 10px 15px 10px 13px;
}

.jetpack-message .squeezer {
	text-align: right;
}

.jetpack-message h4 {
	margin: 0 0 10px 10px;
}

.more-info {
	margin: 0 15px 5px 12px;
	background: transparent url(images/header-clouds-sm.png) bottom right repeat-x;
}

.more-info .jp-close {
	left: 0;
	right: auto;
	padding: 0 6px 0 4px;
	border-radius: 3px;
	border-top-left-radius: 0;
	border-bottom-left-radius: 0;
}

.more-info div.jp-info-img {
	float: left;
	margin: 0 20px 0 30px;
}

.jetpack-module {
	float: right;
	margin: 0 15px 15px 0;
	padding: 15px 15px 35px 0;
}

.jetpack-module div.module-image {
	float: left;
	margin: 0 10px 5px 0;
	border-radius: 0;
	border-top-right-radius: 5px;
	border-bottom-right-radius: 5px;
}

.jetpack-module div.module-image p {
	border-radius: 0;
	border-bottom-right-radius: 5px;
}

.jetpack-module .jetpack-module-actions {
	right: 15px;
	left: auto;
}

.placeholder h3 {
	margin-left: 15px;
	margin-right: auto;
}

#jp-footer .automattic {
	padding-right: 3px;
	padding-left: 0;
}

#jp-footer .automattic span {
	margin: 0 1px 0 5px;
}
