<?php
/**
 * Module Name: Photon
 * Module Description: Give your site a boost by loading images from the WordPress.com content delivery network.
 * Sort Order: 15
 * First Introduced: 2.0
 * Requires Connection: Yes
 * Auto Activate: No
 * Module Tags: Photos and Videos, Appearance
 */

Jetpack_Photon::instance();