<?php

/**
 * Module Name: Carousel
 * Module Description: Transform your standard image galleries into an immersive full-screen experience.
 * Sort Order: 4
 * First Introduced: 1.5
 * Requires Connection: No
 * Auto Activate: No
 * Module Tags: Photos and Videos
 */

include dirname( __FILE__ ) . '/carousel/jetpack-carousel.php';
