<?php

/**
 * Module Name: Widget Visibility
 * Module Description: Control what pages your widgets appear on.
 * First Introduced: 2.4
 * Requires Connection: No
 * Auto Activate: Yes
 * Module Tags: Appearance
 */

include dirname( __FILE__ ) . "/widget-visibility/widget-conditions.php";
