img.mojo-thumbnail:hover {
	/* IE 8 */
	-ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
	/* IE 5-7 */
	filter: alpha(opacity=80);
	/* Netscape */
	-moz-opacity: 0.8;
	/* Safari 1.x */
	-khtml-opacity: 0.8;
	/* Good browsers */
	opacity: 0.8;
}
input.mm-btn-primary{
	padding: 2px 10px;
	line-height: 24px;
	font-size:16px;
}
.mm-btn-primary{
	-moz-user-select: none;
	background-color: #EEEEEE;
	background-image: none;
	border: 0 none;
	border-radius: 3px;
	box-shadow: 0 2px 1px -1px rgba(0, 0, 0, 0.15);
	cursor: pointer;
	display: inline-block;
	font-size: 16px;
	padding: 6px 8px;
	line-height: 16px;
	text-align: center;
	text-decoration: none;
	transform: translateZ(0px);
	transition: background-color 300ms ease-in-out 0s;
	vertical-align: middle;
	white-space: nowrap;
	background-color: #92C933;
	color: #fff;
}
.mm-btn-primary:hover{
	background-color: #74A029;
}
#mojo-sg-form{
	position: relative;
	top: 66px;
}
#mojo-sg-form p{
	line-height: 2.8rem;
	padding-left: 25px;
}
#mojo-sg-form .mm-btn-primary{
	display: block;
	margin: 0 auto;
	font-size: 16px;
	font-weight: bold;
	line-height: 20px;
	padding: 14px 30px;
}
#TB_title{
	background-color: #3B3F41 !important;
}
#mojo-sg-form label{
	width: 200px;
	display: inline-block;
	margin: 10px 0;
	font-size: 14px;
}
#mojo-sg-form select{
	width: 160px;
	display: inline-block;
}
#mojo-sg-form input[type="submit"] {
	cursor: pointer;
}
.mm_sg_header{
	background-color: #3B3F41;
	left: 0;
	position: absolute;
	top: 27px;
	width: 670px;
	padding-bottom: 10px;
}
.mm_sg_header img{
	display: block;
	margin: 0 auto;
}

.toplevel_page_mojo-themes .theme-browser .theme{
	background: none repeat scroll 0 0 #fff;
}

.toplevel_page_mojo-themes .theme-browser .theme .theme-screenshot:after{
	padding-top: 60%;
}

.toplevel_page_mojo-themes .theme-browser .theme .mojo-theme-actions{
	position: relative;
	opacity: 1;
}

.toplevel_page_mojo-themes .theme-browser .theme .mojo-theme-actions .button-secondary,
.toplevel_page_mojo-themes .theme-browser .theme .mojo-theme-actions .mm-btn-primary{
	margin: 5px 0 5px 5px;
}

.toplevel_page_mojo-themes .theme-browser .theme .mojo-theme-actions form{
	display: inline-block;
}

.toplevel_page_mojo-themes .theme-browser .theme .mojo-theme-actions .price{
	display: inline-block;
	position: absolute;
	right: 0;
	bottom: 0;
	padding: 10px;
	font-size: 1rem;
	padding: 15px 10px;
}

.wp-full-overlay-sidebar{
	box-shadow: 0px 0px 10px 0px #000;
}

.admin_page_mojo-theme-preview .theme-details .theme-version,
.admin_page_mojo-theme-preview .theme-details .theme-updated,
.admin_page_mojo-theme-preview .theme-details .theme-sales {
	margin: 15px 0;
	display: block;
	text-align: left;
	float: none;
}