#services-config {
	background: #f1f1f1;
	border: 1px #e3e3e3 solid;
	border-radius: 6px;
	-moz-border-radius: 6px;
	-webkit-border-radius: 6px;
	margin-top:15px;
	min-width: 700px;
	width: 100%;
	float: left;
	margin-bottom: 25px;
}

#available-services,#enabled-services,#live-preview{
	padding:20px 20px 0px 20px;
	width: 100%;
}

#enabled-services {
	padding: 20px;
}

#live-preview {
	padding: 20px 20px 10px 20px;
}

#available-services{
	border-bottom: 1px #e3e3e3 solid;
}

#available-services h3,#enabled-services h3,#live-preview h3{
	padding: 0px;
	margin-top: 0px;
}

.description{
	width: 180px;
	vertical-align: top;
}

.description p{
	font-size: 11px;
}

.services {
	padding: 0px 20px;
	vertical-align: top;
}

.services ul{
}

.services ul li {
	float: left;
	border: 1px #e3e3e3 solid;
	border-radius: 6px;
	-moz-border-radius: 6px;
	-webkit-border-radius: 6px;
	padding: 5px 10px 5px 24px;
	margin-right: 5px !important;
	cursor: move;
}

.services ul li.divider {
	border: none;
	padding: 0;
	background: none;
	cursor: default;
}

.preview {
	float: left !important;
	width: 98%;
}

.services ul.preview li, .services ul.archive li {
	border: none;
}


.services ul li#facebook, #available-services .preview-facebook div.option-smart-off{background: #FFF url(images/facebook.png) no-repeat 4px 5px;}
.services ul li#twitter, #available-services .preview-twitter div.option-smart-off{background: #FFF url(images/twitter.png?1) no-repeat 4px 5px;}
.services ul li#wordpress, #available-services .preview-wordpress{background: #FFF url(images/wordpress.png) no-repeat 4px 5px;}
.services ul li#digg, #available-services .preview-digg div.option-smart-off{background: #FFF url(images/digg.png) no-repeat 4px 5px;}
.services ul li#reddit, #available-services .preview-reddit div.option-smart-off{background: #FFF url(images/reddit.png) no-repeat 4px 5px;}
.services ul li#stumbleupon, #available-services .preview-stumbleupon div.option-smart-off{background: #FFF url(images/stumbleupon.png) no-repeat 4px 5px;}
.services ul li#email, #available-services .preview-email{background: #FFF url(images/email.png) no-repeat 4px 5px; padding-right: 10px;}
.services ul li#print, #available-services .preview-print{background: #FFF url(images/print.png) no-repeat 4px 5px; padding-right: 10px;}
.services ul li#press-this, #available-services .preview-press-this{background: #FFF url(images/wordpress.png) no-repeat 4px 5px; padding-right: 10px;}
.services ul li#linkedin, #available-services .preview-linkedin div.option-smart-off{background: #FFF url(images/linkedin.png) no-repeat 4px 5px;}
.services ul li#tumblr,#available-services .preview-tumblr{background: #FFF url(images/tumblr.png) no-repeat 4px 5px; padding-right: 10px;}
.services ul li#google-plus-1,#available-services .preview-google-plus-1{background: #FFF url(images/googleplus1.png) no-repeat 4px 5px; padding-right: 10px;}
.services ul li#pinterest,#available-services .preview-pinterest{background: #FFF url(images/pinterest.png) no-repeat 5px 6px; padding-right: 10px;}
.services ul li#pocket,#available-services .preview-pocket{background: #FFF url(images/pocket.png) no-repeat 4px 5px; padding-right: 10px;}
.services ul li#kindle,#available-services .preview-kindle{background: #FFF url(images/kindle.png) no-repeat 4px 5px; padding-right: 10px;}
.services ul li.share-custom, #available-services .preview-custom{background: #FFF url(images/custom.png) no-repeat 4px 5px; no-repeat 4px 5px; padding-right: 10px;}



/****************************************************************************/

.preview li.preview-item {
	margin: 0 15px 0 0;
	background-position: 0px 5px;
	padding: 5px 0px 5px 20px;
	border: none;
	cursor: default;
}

.preview li.preview-digg,
.preview li.preview-reddit,
.preview li.preview-stumbleupon,
.preview li.preview-facebook,
.preview li.preview-twitter,
.preview li.preview-linkedin,
.preview li.preview-tumblr {
	padding: 0;
}

.preview-digg .option-smart-on {
	background: #FFF url(images/smart-digg.png) no-repeat top left;
	background-size: 76px 17px;
	width:76px;
	height:17px;
	margin-top: 2px;
}

.preview-reddit .option-smart-on {
	background: #FFF url(images/smart-reddit.png) no-repeat top left;
	background-size: 104px 21px;
	width:104px;
	height:21px;
}

.preview-stumbleupon .option-smart-on {
	background: #FFF url(images/smart-stumbleupon.png) no-repeat top left;
	background-size: 74px 18px;
	width: 74px;
	height: 18px;
	margin-top: 1px;
}

.preview-facebook .option-smart-on {
	background: #FFF url(images/smart-like.png) no-repeat top left;
	background-size: 50px 20px;
	width:50px;
	height:20px;
}

.preview-twitter .option-smart-on {
	background: #FFF url(images/smart-twitter.png?1) no-repeat top left;
	background-size: 92px 20px;
	width:92px;
	height:20px;
}

.preview-linkedin .option-smart-on {
	background: #FFF url(images/linkedin-smart.png) no-repeat top center;
	background-size: 99px 18px;
	width:99px;
	height:18px;
	margin-top: 1px;
}

.preview-google-plus-1 .option-smart-on {
	background: #FFF url(images/smart-googleplus1.png) no-repeat top left;
	background-size: 96px 20px;
	width: 96px;
	height: 20px;
}

.preview-tumblr .option-smart-on {
	background: #FFF url(images/smart-tumblr.png) no-repeat top left;
	background-size: 62px 20px;
	width: 62px;
	height: 20px;
}

.preview-pinterest .option-smart-on {
	background: #FFF url(images/smart-pinterest.png) no-repeat top left;
	background-size: 58px 20px;
	width: 58px;
	height: 20px;
}

.preview-pinterest .option-smart-on {
	background: #FFF url(images/smart-pinterest.png) no-repeat top left;
	background-size: 58px 20px;
	width: 58px;
	height: 20px;
}

.preview-pocket .option-smart-on {
	background: #FFF url(images/smart-pocket.png) no-repeat top left;
	background-size: 60px 20px;
	width: 60px;
	height: 20px;
}

.services .preview li.share-custom {
	border-radius: 6px;
	-moz-border-radius: 6px;
	-webkit-border-radius: 6px;
	background:url("images/sharing-hidden.png") no-repeat scroll 0px center #FFFFFF;
	float: left;
	line-height: 22px;
	padding: 0 8px 0 21px;
	margin: 1px 0 0 0;
}

.services .preview li.share-custom a {
	color: #333;
	text-decoration: none;
}

.services ul li.end-fix {
	clear:both;
	float:none;
	visibility:hidden;
	padding:0;
	margin:0;
	height:20px;
	width:0;
}

#enabled-services{
	border-top: 1px #FFF solid;
	border-bottom: 1px #e3e3e3 solid;
}

#enabled-services h2{
	font-size:20px;
	padding-top:0px;
	font-weight: normal !important;
	color: #999;
}

#live-preview h2{
	font-size:20px;
	font-weight: normal !important;
	color: #e3e3e3;
}

#live-preview{
	background: #FFF;
	border-bottom-left-radius:6px 6px;
	border-bottom-right-radius:6px 6px;
	-moz-border-radius-bottomleft: 6px;
	-moz-border-radius-bottomright: 6px;
}

.clearing{
	clear: both;
}

	.options .options-left{
		float: left;
	}

	.input label{
		font-size: 11px;
		line-height: 16px;
	}

	.advanced-form {
		padding: 10px 14px 8px 10px;
		margin-left: -24px;
		display: none;
		border-top: 1px #e3e3e3 solid;
		margin-top:4px;
	}

	.utility{
		float: right;
		padding-top:10px;
		padding-right: 10px;
		font-size: 10px;
	}

	.advanced input[type=submit]{
		float: left;
		margin-top:10px;
		margin-right: 10px;
	}

.services li.dropzone {
	border: 1px dashed #999;
	background: #e3e3e3;
}

.advanced-form .form-table th {
	width: auto !important;
}

.advanced-form .button-secondary {
	margin-top: 0 !important;
}

#share-drop-target {
}

#hidden-drop-target {
	background: #e1e1e1;
	border: 1px solid #cdcdcd;
	border-radius: 6px;
	-moz-border-radius: 6px;
	-webkit-border-radius: 6px;
	width: 29%;
	padding: 10px;
	vertical-align: top;
}

#hidden-drop-target p {
	font-size: 10px;
	margin: 0 0 10px 0;

}

.sharing-hidden .inner {
	position: absolute;
    border: 2px solid #6e6e6e;
    padding: 15px 0px;
    background: #fff;
}


.sharing-hidden ul {
    margin: 0 !important;
}

.services .sharing-hidden li {
	margin: 0px 10px 0px 10px;
	background-color: transparent;
}

.sharing-hidden li.share-end {
    clear: both;
    height: 0;
    padding: 0px !important;
    margin: 0px !important;
    width: 0;
    visibility: hidden;
    float: none;
}

.preview .sharing-label {
	font-weight: bold;
	border: 0;
	padding: 4px 6px 0 0;
}

#services-config a.remove {
	background: #ddd;
	color: #fff;
	padding: 0px 4px 2px;
	border-radius: 15px;
	-moz-border-radius: 15px;
	-webkit-border-radius: 15px;
	text-decoration: none;
	font-weight: bold;
	font-size: 10px;
}

#services-config a.remove:hover {
	background: #f00;
}




@media print,
  (-o-min-device-pixel-ratio: 5/4),
  (-webkit-min-device-pixel-ratio: 1.25),
  (min-resolution: 120dpi) {

	.services ul li#facebook, #available-services .preview-facebook div.option-smart-off{background: #FFF url(images/facebook@2x.png) no-repeat 4px 5px;}
	.services ul li#twitter, #available-services .preview-twitter div.option-smart-off{background: #FFF url(images/twitter@2x.png?1) no-repeat 4px 5px;}
	.services ul li#wordpress, #available-services .preview-wordpress{background: #FFF url(images/wordpress@2x.png?1) no-repeat 4px 5px;}
	.services ul li#digg, #available-services .preview-digg div.option-smart-off{background: #FFF url(images/digg@2x.png) no-repeat 4px 5px;}
	.services ul li#reddit, #available-services .preview-reddit div.option-smart-off{background: #FFF url(images/reddit@2x.png) no-repeat 4px 5px;}
	.services ul li#stumbleupon, #available-services .preview-stumbleupon div.option-smart-off{background: #FFF url(images/stumbleupon@2x.png) no-repeat 4px 5px;}
	.services ul li#email, #available-services .preview-email{background: #FFF url(images/email@2x.png) no-repeat 4px 5px; padding-right: 10px;}
	.services ul li#print, #available-services .preview-print{background: #FFF url(images/print@2x.png) no-repeat 4px 5px; padding-right: 10px;}
	.services ul li#press-this, #available-services .preview-press-this{background: #FFF url(images/wordpress@2x.png) no-repeat 4px 5px; padding-right: 10px;}
	.services ul li#linkedin, #available-services .preview-linkedin div.option-smart-off{background: #FFF url(images/linkedin@2x.png) no-repeat 4px 5px;}
	.services ul li#tumblr,#available-services .preview-tumblr{background: #FFF url(images/tumblr@2x.png) no-repeat 4px 5px; padding-right: 10px;}
	.services ul li#google-plus-1,#available-services .preview-google-plus-1{background: #FFF url(images/googleplus1@2x.png) no-repeat 4px 5px; padding-right: 10px;}
	.services ul li#pinterest,#available-services .preview-pinterest{background: #FFF url(images/pinterest@2x.png) no-repeat 4px 5px; padding-right: 10px;}
	.services ul li#pocket,#available-services .preview-pocket{background: #FFF url(images/pocket@2x.png) no-repeat 4px 5px; padding-right: 10px;}
	.services ul li#kindle,#available-services .preview-kindle{background: #FFF url(images/kindle@2x.png) no-repeat 4px 5px; padding-right: 10px;}
	.services ul li.share-custom, #available-services .preview-custom{background: #FFF url(images/custom@2x.png) no-repeat 4px 5px; no-repeat 4px 5px; padding-right: 10px;}

	.services ul li#facebook, #available-services .preview-facebook div.option-smart-off,
	.services ul li#twitter, #available-services .preview-twitter div.option-smart-off,
	.services ul li#wordpress, #available-services .preview-wordpress,
	.services ul li#digg, #available-services .preview-digg div.option-smart-off,
	.services ul li#reddit, #available-services .preview-reddit div.option-smart-off,
	.services ul li#stumbleupon, #available-services .preview-stumbleupon div.option-smart-off,
	.services ul li#email, #available-services .preview-email,
	.services ul li#print, #available-services .preview-print,
	.services ul li#press-this, #available-services .preview-press-this,
	.services ul li#linkedin, #available-services .preview-linkedin div.option-smart-off,
	.services ul li#tumblr,#available-services .preview-tumblr,
	.services ul li#google-plus-1,#available-services .preview-google-plus-1,
	.services ul li#pinterest,#available-services .preview-pinterest,
	.services ul li#pocket,#available-services .preview-pocket,
	.services ul li#kindle,#available-services .preview-kindle,
	.services ul li.share-custom, #available-services .preview-custom{
		background-size: 16px 16px;
	}

	.preview-digg .option-smart-on {
		background-image: url(images/smart-digg@2x.png);
	}

	.preview-reddit .option-smart-on {
		background-image: url(images/smart-reddit@2x.png);
	}

	.preview-stumbleupon .option-smart-on {
		background-image: url(images/smart-stumbleupon@2x.png);
	}

	.preview-facebook .option-smart-on {
		background-image: url(images/smart-like@2x.png);
	}

	.preview-twitter .option-smart-on {
		background-image: url(images/smart-twitter@2x.png);
	}

	.preview-linkedin .option-smart-on {
		background-image: url(images/linkedin-smart@2x.png);
	}

	.preview-google-plus-1 .option-smart-on {
		background-image: url(images/smart-googleplus1@2x.png);
	}

	.preview-tumblr .option-smart-on {
		background-image: url(images/smart-tumblr@2x.png);
	}

	.preview-pinterest .option-smart-on {
		background-image: url(images/smart-pinterest@2x.png);
	}

	.preview-pocket .option-smart-on {
		background-image: url(images/smart-pocket@2x.png);
	}

}